from service.app_a.funs.open.haohan.funs_open_haohan_rights import FunsOpenHaohanRights
from service.app_a.funs.open.haohan.funs_open_haohan_relation import FunsOpenHaohanRelation


class FunsOpenHaohan(FunsOpenHaohanRights, FunsOpenHaohanRelation):
    pass

